Function state_sync_v1::network::network_endpoint_config [−][src]
pub fn network_endpoint_config() -> AppConfigExpand description
Configuration for the network endpoints to support state sync.
pub fn network_endpoint_config() -> AppConfigConfiguration for the network endpoints to support state sync.